@@ -1,7 +1,7 @@
-/*
+﻿/*
  * RecoilPaintDotNet.cs - Paint.NET file type plugin
  *
- * Copyright (C) 2013-2014  Piotr Fusik and Adrian Matoga
+ * Copyright (C) 2013-2015  Piotr Fusik
  *
  * This file is part of RECOIL (Retro Computer Image Library),
  * see http://recoil.sourceforge.net
@@ -24,12 +24,20 @@
 using System;
 using System.Drawing;
 using System.Drawing.Imaging;
-using System.IO;
+using System.Reflection;
 using System.Runtime.InteropServices;
 
 using PaintDotNet;
 using Recoil;
 
+[assembly: AssemblyTitle("Paint.NET RECOIL plugin")]
+//[assembly: AssemblyDescription("Decodes images in native formats of classic computers")]
+[assembly: AssemblyCompany("Piotr Fusik")]
+[assembly: AssemblyProduct("RECOIL")]
+[assembly: AssemblyCopyright("Copyright © 2013-2015")]
+[assembly: AssemblyVersion(RECOIL.Version + ".0")]
+[assembly: AssemblyFileVersion(RECOIL.Version + ".0")]
+
 namespace Recoil.PaintDotNet
 {
 	// Paint.NET gives us a Stream without the filename, so I create a distinct FileType object for each extension.
@@ -41,14 +49,14 @@ namespace Recoil.PaintDotNet
 		{
 		}
 
-		protected override Document OnLoad(Stream input)
+		protected override Document OnLoad(System.IO.Stream input)
 		{
 			// Read.
 			byte[] content = new byte[RECOIL.MaxContentLength];
 			int contentLength = input.Read(content, 0, content.Length);
-			RECOIL recoil = new RECOIL();
 
 			// Decode.
+			RECOIL recoil = new RECOIL();
 			if (!recoil.Decode(DefaultExtension, content, contentLength))
 				throw new Exception("Decoding error");
 			int width = recoil.GetWidth();
@@ -75,6 +83,7 @@ namespace Recoil.PaintDotNet
 				new RecoilFileType(".4pm", "AtariTools-800 4 mono players and 4 mono missiles"),
 				new RecoilFileType(".64c", "8x8 font, mono"),
 				new RecoilFileType(".a4r", "Anime 4ever; 80x256, 16-level grayscale, compressed"),
+				new RecoilFileType(".a64", "Wigmore Artist 64; 160x200, 16 colors"),
 				new RecoilFileType(".aas", "Art Studio; 320x200, 16 colors"),
 				new RecoilFileType(".acbm", "Amiga Continuous Bitmap"),
 				new RecoilFileType(".acs", "AtariTools-800 4x8 font, 4 colors"),
@@ -90,6 +99,12 @@ namespace Recoil.PaintDotNet
 				new RecoilFileType(".apv", "80x192, 256 colors, 2 frames"),
 				new RecoilFileType(".art", "Art Studio or Art Director or Ascii-Art Editor or Artist by David Eaton"),
 				new RecoilFileType(".atr", "ZX Spectrum attributes"),
+				new RecoilFileType(".bb0", "Mode 0; 640x256, mono"),
+				new RecoilFileType(".bb1", "Mode 1; 320x256, 4 colors"),
+				new RecoilFileType(".bb2", "Mode 2; 160x256, 8 colors"),
+				new RecoilFileType(".bb4", "Mode 4; 320x256, mono"),
+				new RecoilFileType(".bb5", "Mode 5; 160x256, 4 colors"),
+				new RecoilFileType(".bbg", "LdPic"),
 				new RecoilFileType(".bfli", "Big FLI; 148x400, 16 colors"),
 				new RecoilFileType(".bg9", "160x192, 16-level grayscale"),
 				new RecoilFileType(".bgp", "Bugbiter APAC239i; 80x239, 256 colors, 2 frames"),
@@ -121,6 +136,7 @@ namespace Recoil.PaintDotNet
 				new RecoilFileType(".dgi", "Digi Paint; 80x192, 256 colors, 2 frames"),
 				new RecoilFileType(".dgp", "Digi Paint; 80x192, 256 colors, 2 frames"),
 				new RecoilFileType(".dgu", "DuneGraph; 320x200, 256 colors"),
+				new RecoilFileType(".dhr", "Double High-Resolution; 560x192, mono"),
 				new RecoilFileType(".din", "320x192, 10 colors, 2 frames"),
 				new RecoilFileType(".dlm", "Dir Logo Maker; 88x128, mono"),
 				new RecoilFileType(".dlp", "Drazlace; up to 320x200, 2 frames, compressed"),
@@ -131,8 +147,12 @@ namespace Recoil.PaintDotNet
 				new RecoilFileType(".drl", "Drazlace; up to 320x200, 2 frames"),
 				new RecoilFileType(".drp", "Drazpaint; 160x200, 16 colors, compressed"),
 				new RecoilFileType(".drz", "Drazpaint; 160x200, 16 colors"),
+				new RecoilFileType(".du1", "416x273, 136 colors, 2 frames"),
+				new RecoilFileType(".du2", "832x273, 10 colors, 2 frames"),
+				new RecoilFileType(".duo", "416x273, 136 colors, 2 frames"),
 				new RecoilFileType(".eci", "ECI Graphic Editor; 296x200, 2 frames"),
 				new RecoilFileType(".ecp", "ECI Graphic Editor; 296x200, 2 frames, compressed"),
+				new RecoilFileType(".epa", "Award BIOS logo"),
 				new RecoilFileType(".esc", "EscalPaint; 80x192, 256 colors, 2 frames"),
 				new RecoilFileType(".fd2", "FLI Designer; 148x200, 16 colors"),
 				new RecoilFileType(".ffli", "FFLI; 148x200, 2 frames"),
@@ -157,12 +177,16 @@ namespace Recoil.PaintDotNet
 				new RecoilFileType(".gr7", "Graphics 7; up to 160x120, 4 colors"),
 				new RecoilFileType(".gr8", "Graphics 8; up to 320x240, mono"),
 				new RecoilFileType(".gr9", "Graphics 9; up to 80x240, 16-level grayscale"),
+				new RecoilFileType(".grp", "Screen 2; 256x192, 15 colors"),
 				new RecoilFileType(".gun", "Gunpaint; 296x200, 2 frames"),
 				new RecoilFileType(".ham6", "Hold-And-Modify 6; 4096 colors"),
 				new RecoilFileType(".ham8", "Hold-And-Modify 8; 16777216 colors"),
 				new RecoilFileType(".hbm", "Hires Bitmap; 320x200, mono"),
+				new RecoilFileType(".hci", "320x200, 5 colors, 2 frames"),
 				new RecoilFileType(".hed", "Hi-Eddi; 320x200, 16 colors"),
 				new RecoilFileType(".hfc", "Hires FLI by Crest; 296x112, 16 colors"),
+				new RecoilFileType(".hgb", "HinterGrundBild; 512x256, mono"),
+				new RecoilFileType(".hgr", "High Resolution; 280x192, mono"),
 				new RecoilFileType(".him", "Hires Manager by Cosmos; 296x192, 16 colors, compressed"),
 				new RecoilFileType(".hip", "Hard Interlace Picture; 160x200, grayscale, 2 frames"),
 				new RecoilFileType(".hir", "Hires; 320x200, mono"),
@@ -181,6 +205,7 @@ namespace Recoil.PaintDotNet
 				new RecoilFileType(".ilc", "80x192, 256 colors, 2 frames"),
 				new RecoilFileType(".img", "GEM Bit Image or ZX Spectrum Gigascreen"),
 				new RecoilFileType(".imn", "ICE MIN; 160x192, 80 colors, 2 frames"),
+				new RecoilFileType(".info", "Amiga Icon; 8 colors"),
 				new RecoilFileType(".ing", "ING 15; 160x200, 7 colors, 2 frames"),
 				new RecoilFileType(".inp", "160x200, 7 colors, 2 frames"),
 				new RecoilFileType(".int", "INT95a; up to 160x239, 16 colors, 2 frames"),
@@ -206,6 +231,7 @@ namespace Recoil.PaintDotNet
 				new RecoilFileType(".mch", "Graph2Font; up to 176x240, 128 colors"),
 				new RecoilFileType(".mci", "True Paint; 320x200, 2 frames"),
 				new RecoilFileType(".mcp", "McPainter; 160x200, 16 colors, 2 frames"),
+				new RecoilFileType(".mcpp", "Paradox; 160x100, 16 colors"),
 				new RecoilFileType(".mcs", "160x192, 9 colors"),
 				new RecoilFileType(".mg1", "MultiArtist; 256x192, 2 frames"),
 				new RecoilFileType(".mg2", "MultiArtist; 256x192, 2 frames"),
@@ -218,9 +244,12 @@ namespace Recoil.PaintDotNet
 				new RecoilFileType(".mle", "Multi-Lace Editor; 320x56, 10 colors, 2 frames"),
 				new RecoilFileType(".mon", "Mono Magic; 320x200, mono"),
 				new RecoilFileType(".mpp", "Multi Palette Picture; up to 416x273, 1 or 2 frames"),
+				new RecoilFileType(".msp", "Microsoft Paint version 1 or 2; mono"),
 				new RecoilFileType(".neo", "NEOchrome"),
 				new RecoilFileType(".nlq", "Daisy-Dot; 19x16 font, mono"),
 				new RecoilFileType(".ocp", "Advanced Art Studio; 160x200, 16 colors"),
+				new RecoilFileType(".p", "Sinclair BASIC; 256x192, mono"),
+				new RecoilFileType(".p4i", "Up to 320x200, 121 colors"),
 				new RecoilFileType(".p64", "Picasso 64; 160x200, 16 colors"),
 				new RecoilFileType(".pac", "STAD; 640x400, mono, compressed"),
 				new RecoilFileType(".pc1", "DEGAS Elite; 320x200, 16 colors, compressed"),
@@ -236,6 +265,7 @@ namespace Recoil.PaintDotNet
 				new RecoilFileType(".pi4", "Fuckpaint; 320x240 or 320x200, 256 colors"),
 				new RecoilFileType(".pi9", "Fuckpaint; 320x240 or 320x200, 256 colors"),
 				new RecoilFileType(".pic", "Koala MicroIllustrator; 160x192, 4 colors, compressed"),
+				new RecoilFileType(".pl4", "320x200, 256 colors, 2 frames, compressed"),
 				new RecoilFileType(".pla", "AtariTools-800 player; 8x240, mono"),
 				new RecoilFileType(".plm", "Plama 256; 80x96, 256 colors"),
 				new RecoilFileType(".pmd", "PMG Designer by Henryk Karpowicz"),
@@ -251,19 +281,24 @@ namespace Recoil.PaintDotNet
 				new RecoilFileType(".rm4", "Rambrandt; 160x192, 99 colors"),
 				new RecoilFileType(".rp", "Rainbow Painter; 160x200, 16 colors"),
 				new RecoilFileType(".rpm", "Run Paint; 160x200, 16 colors"),
+				new RecoilFileType(".rys", "Mamut; 160x96, 4 colors"),
 				new RecoilFileType(".sar", "Saracen Paint; 160x200, 16 colors"),
 				new RecoilFileType(".sc2", "Screen 2; 256x192, 15 colors"),
 				new RecoilFileType(".sc8", "Screen 8; 256x212, 256 colors"),
+				new RecoilFileType(".sca", "Screen 10; 256x212, 12515 colors"),
+				new RecoilFileType(".scc", "Screen 12; 256x212, 19268 colors"),
 				new RecoilFileType(".scr", "256x192, 15 colors"),
 				new RecoilFileType(".scs4", "Mode 4; 256x192, 16 colors"),
 				new RecoilFileType(".sge", "Semi-Graphic logos Editor; 320x192, mono"),
 				new RecoilFileType(".shc", "SAMAR Hi-res Interlace with Map of Colours; 320x192, 2 frames"),
 				new RecoilFileType(".shp", "Blazing Paddles or Movie Maker shapes"),
+				new RecoilFileType(".shr", "320x200, 256 colors"),
 				new RecoilFileType(".sif", "Super-IRG 4x8 font; 4 colors, 2 frames"),
 				new RecoilFileType(".spc", "Spectrum 512 Compressed or The Graphics Magician Picture Painter"),
 				new RecoilFileType(".sps", "Spectrum 512 Smooshed; 320x199, 512 colors, compressed"),
 				new RecoilFileType(".spu", "Spectrum 512; 320x199, 512 colors"),
 				new RecoilFileType(".sr8", "Graph Saurus; 256x212, 256 colors, compressed"),
+				new RecoilFileType(".srs", "Screen 12; 256x212, 19268 colors"),
 				new RecoilFileType(".sxs", "16x16 font, mono"),
 				new RecoilFileType(".tip", "Taquart Interlace Picture; up to 160x119, 2 frames"),
 				new RecoilFileType(".tn1", "Tiny Stuff; 320x200, 16 colors, compressed"),
@@ -272,6 +307,7 @@ namespace Recoil.PaintDotNet
 				new RecoilFileType(".tny", "Tiny Stuff; compressed"),
 				new RecoilFileType(".trp", "EggPaint; 65536 colors"),
 				new RecoilFileType(".tru", "IndyPaint; 65536 colors"),
+				new RecoilFileType(".wig", "Wigmore Artist 64; 160x200, 16 colors"),
 				new RecoilFileType(".wnd", "Blazing Paddles window; up to 160x192, 4 colors"),
 				new RecoilFileType(".vic", "Generic C64; up to 320x200, 16 colors"),
 				new RecoilFileType(".vid", "Vidcom 64; 160x200, 16 colors"),
